==> nextcloud-29.0.5.tgz: nextcloud/apps/circles/l10n/lt_LT.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Jūs ištrynėte {circle}",
    "{author} deleted {circle}" : "{author} ištrynė {circle}",
    "You removed {member} from {circle}" : "Jūs pašalinote {member} iš {circle}",
    "You joined {circle}" : "Jūs prisijungėte prie {circle}",
    "{member} joined {circle}" : "{member} prisijungė prie {circle}",
    "You accepted the invitation to join {circle}" : "Jūs priėmėte pakvietimą prisijungti prie {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} priėmė pakvietimą prisijungti prie {circle}",
    "You added {member} as member to {circle}" : "Jūs pridėjote {member} kaip narį į {circle}",
    "You have been added as member to {circle} by {author}" : "{author} pridėjo jus kaip narį į {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} priodėjo {member} kaip narys prie {circle}",
    "You added {external} to {circle}" : "Jūs pridėjote {external} į {circle}",
    "{external} has been added to {circle} by {author}" : "{author} pridėjo {external} į {circle}",
    "You accepted {member}'s request to join {circle}" : "Jūs priėmėte {member} prašymą prisijungti prie {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} priėmė Jūsų prašymą prisijungti prie {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} priėmė {member}  prašymą prisijungti prie {circle} ",
    "You left {circle}" : "Jūs išėjote iš {circle}",
    "{member} left {circle}" : "{member} išėjo iš {circle}",
    "You declined the invitation to join {circle}" : "Jūs atmetėte pakvietimą prisijungti prie {circle}",
    "{member} declined an invitation to join {circle}" : "{member} atmetė pakvietimą prisijungti prie {circle}",
    "You cancelled your request to join {circle}" : "Jūs atšaukėte prašymą prisijungti prie {circle}",
    "You have been removed from {circle} by {author}" : "{author} pašalino jus iš {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} pašalino {member} iš {circle}",
    "You removed {external} from {circle}" : "Jūs pašalinote {external} iš {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} pašalino {external} iš {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Jūs atmetėte {member} kvietimą prisijungti prie {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} atmetė Jūsų kvietimą prisijungti prie {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} atmetė {member} pakvietimą prisijungti prie {circle}",
    "You dismissed {member}'s request to join {circle}" : "Jūs atmetėte {member} prašymą prisijungti prie {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} atmetė Jūsų prašymą prisijungti prie {circle}  ",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} atmetė {member} prašymą prisijungti prie {circle}",
    "You invited {member} to join {circle}" : "Jūs pakvietėte {member} prisijungti prie {circle}",
    "You have been invited to join {circle} by {author}" : "{author} pakvietė jus prisijungti prie {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} pakvietė {member} prisijungti prie {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Jūs pakeitėte {member} lygį {circle} į %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} pakeitė Jūsų lygį {circle} į %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} pakeitė {circle}  {member} lygį į %1$s",
    "You sent a request to join {circle}" : "Jūs išsiuntėte užklausą prisijungti prie {circle}",
    "{member} sent a request to join {circle}" : "{member} išsiuntė užklausą prisijungti prie {circle}",
    "You are the new owner of {circle}" : "Jūs esate rato {circle} savininkas",
    "{member} is the new owner of {circle}" : "{member} yra naujas rato {circle} savininkas",
    "Shared to Circles" : "Bendrinama su  bendrystės ratu",
    "Personal" : "Asmeniniai",
    "System" : "Sistema",
    "Visible" : "Matoma",
    "Open" : "Atverti",
    "Password protected" : "Apsaugota slaptažodžiu",
    "Hidden" : "Paslėpta",
    "Local" : "Vietinis",
    "Root" : "Šaknis",
    "Federated" : "Federacinis",
    "Email address" : "El. pašto adresas",
    "Contact" : "Adresatas",
    "Circle" : "Ratas",
    "Member" : "Narys",
    "Moderator" : "Moderatorius",
    "Admin" : "Administratorius",
    "Owner" : "Savininkas",
    "%s shared »%s« with you." : "%s pradėjo bendrinti »%s« su jumis.",
    "%s on %s" : "%s ant %s",
    "Password to access »%1$s« shared to you by %2$s" : "%2$s pasidalino slaptažodžiu, reikalingu atverti „%1$s“",
    "Password to access »%s«" : "Slaptažodis, skirtas prieigai prie „%s“",
    "It is protected with the following password:" : "Apsaugota šiuo slaptažodžiu:",
    "%1$s via %2$s" : "%1$s per %2$s",
    "Click the button below to open it." : "Norėdami jį atverti, spustelėkite mygtuką žemiau.",
    "Open »%s«" : "Atverti »%s«",
    "Password to access files shared to you by %1$s" : "Slaptažodis, skirtas pasiekti failus, kuriuos su jumis bendrino %1$s",
    "Password to access files" : "Prieigos prie failų slaptažodis",
    "%s shared multiple files with you." : "%s bendrino kelis failus su Jumis.",
    "Files" : "Failai",
    "This feature is not available for personal circles" : "Ši ypatybė nėra prieinama asmeniniams ratams",
    "This member is not a moderator" : "Šis narys nėra moderatorius",
    "Insufficient privileges" : "Nepakanka teisių",
    "This member does not exist" : "Šio nario nėra",
    "Level cannot be changed for this type of member" : "Šio tipo naudotojui negali būti pakeistas lygis.",
    "You are already a member of this circle" : "Jūs jau esate šio rato narys",
    "You have been blocked from this circle" : "Jūs buvote blokuotas šiame bendrinimo rate",
    "You are now a member of the Circle \"%2$s\"" : "Jūs jau esate bendrinimo rato \"%2$s\" narys.",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s pakvietė jus  prisijungti prie \"%2$s\" bendrinimo rato.",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$sišsiuntė prašymą prisijungti prie \"%2$s\" bendrinimo rato.",
    "Accept" : "Priimti",
    "Refuse" : "Atsisakyti",
    "Leave the circle" : "Išeiti iš rato",
    "%s" : "%s",
    "No files in here" : "Čia failų nėra",
    "No entries found in this folder" : "Šiame aplanke nerasta jokių įrašų",
    "Name" : "Vardas",
    "Size" : "Dydis",
    "Modified" : "Pakeistas",
    "Circles" : "Ratai",
    "Circles' files" : "Ratų failai",
    "Select circles to filter by" : "Pasirinkite ratą, pagal kurį norite filtruoti",
    "No circles found" : "Nerasta jokių ratų",
    "Please select circles to filter by" : "Prašome, pasirinkite ratą, pagal kurį norite filtruoti",
    "No files found for the selected circles" : "Pasiranktam ratui nerasta jokių failų",
    "You created the circle {circle}" : "Jūs sukūrėte ratą {circle}",
    "{author} created the circle {circle}" : "{author} sukūrė ratą {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Įvykiai, vykstantys  <strong>Rate</strong>, kurio narys Jūs esate",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Svarbūs įvykiai <strong>Rate</strong>, kuriame Jūs esate moderatorius",
    "On global events happening in any <strong>Circle</strong>" : "Visuotiniai įvykiai vykstantys  bet kuriame <strong>Rate</strong>",
    "Email Address" : "El. pašto adresas",
    "Circle not found" : "Ratas nerastas",
    "Circle not found " : "Bendrinio ratas nerastas",
    "Federated link not found" : "Federacinė nuoroda nerasta",
    "The circle is not federated" : "Šis ratas nėra federacinis",
    "You cannot join this circle" : "Jūs negalite prisijungti prie šio rato",
    "This member is the owner of the circle" : "Šis narys yra rato savininkas",
    "Personal Circle" : "Asmeninis ratas",
    "You need a specify a type of circle" : "Jūs turite nurodyti rato tipą",
    "A circle with that name exists" : "Ratas tokiu pavadinimu jau yra",
    "This member is not the owner of the circle" : "Šis narys nėra rato savininkas",
    "This member is not an admin of the circle" : "Šis narys nėra rato administratorius",
    "This group does not exist" : "Šios grupės nėra",
    "This group is already linked to the circle" : "Ši grupė jau yra susieta su ratu",
    "Group cannot be set as owner of a circle" : "Grupė negali būti nustatyta kaip rato savininkė",
    "now" : "dabar",
    "Email format is not valid" : "Neteisingas el. pašto formatas",
    "This contact is not available" : "Šis adresatas yra neprieinamas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-30.0.13.tgz: nextcloud/apps/circles/l10n/lt_LT.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Komandos",
    "You deleted {circle}" : "Jūs ištrynėte {circle}",
    "{author} deleted {circle}" : "{author} ištrynė {circle}",
    "You removed {member} from {circle}" : "Jūs pašalinote {member} iš {circle}",
    "You joined {circle}" : "Jūs prisijungėte prie {circle}",
    "{member} joined {circle}" : "{member} prisijungė prie {circle}",
    "You accepted the invitation to join {circle}" : "Jūs priėmėte pakvietimą prisijungti prie {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} priėmė pakvietimą prisijungti prie {circle}",
    "You added {member} as member to {circle}" : "Jūs pridėjote {member} kaip narį į {circle}",
    "You have been added as member to {circle} by {author}" : "{author} pridėjo jus kaip narį į {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} priodėjo {member} kaip narys prie {circle}",
    "You added {external} to {circle}" : "Jūs pridėjote {external} į {circle}",
    "{external} has been added to {circle} by {author}" : "{author} pridėjo {external} į {circle}",
    "You accepted {member}'s request to join {circle}" : "Jūs priėmėte {member} prašymą prisijungti prie {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} priėmė Jūsų prašymą prisijungti prie {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} priėmė {member}  prašymą prisijungti prie {circle} ",
    "You left {circle}" : "Jūs išėjote iš {circle}",
    "{member} left {circle}" : "{member} išėjo iš {circle}",
    "You declined the invitation to join {circle}" : "Jūs atmetėte pakvietimą prisijungti prie {circle}",
    "{member} declined an invitation to join {circle}" : "{member} atmetė pakvietimą prisijungti prie {circle}",
    "You cancelled your request to join {circle}" : "Jūs atšaukėte prašymą prisijungti prie {circle}",
    "You have been removed from {circle} by {author}" : "{author} pašalino jus iš {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} pašalino {member} iš {circle}",
    "You removed {external} from {circle}" : "Jūs pašalinote {external} iš {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} pašalino {external} iš {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Jūs atmetėte {member} kvietimą prisijungti prie {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} atmetė Jūsų kvietimą prisijungti prie {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} atmetė {member} pakvietimą prisijungti prie {circle}",
    "You dismissed {member}'s request to join {circle}" : "Jūs atmetėte {member} prašymą prisijungti prie {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} atmetė Jūsų prašymą prisijungti prie {circle}  ",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} atmetė {member} prašymą prisijungti prie {circle}",
    "You invited {member} to join {circle}" : "Jūs pakvietėte {member} prisijungti prie {circle}",
    "You have been invited to join {circle} by {author}" : "{author} pakvietė jus prisijungti prie {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} pakvietė {member} prisijungti prie {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Jūs pakeitėte {member} lygį {circle} į %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} pakeitė Jūsų lygį {circle} į %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} pakeitė {circle}  {member} lygį į %1$s",
    "You sent a request to join {circle}" : "Jūs išsiuntėte užklausą prisijungti prie {circle}",
    "{member} sent a request to join {circle}" : "{member} išsiuntė užklausą prisijungti prie {circle}",
    "You are the new owner of {circle}" : "Jūs esate rato {circle} savininkas",
    "{member} is the new owner of {circle}" : "{member} yra naujas rato {circle} savininkas",
    "Personal" : "Asmeniniai",
    "System" : "Sistema",
    "Visible" : "Matoma",
    "Open" : "Atverti",
    "Password protected" : "Apsaugota slaptažodžiu",
    "Hidden" : "Paslėpta",
    "Local" : "Vietinis",
    "Root" : "Šaknis",
    "Federated" : "Federacinis",
    "Email address" : "El. pašto adresas",
    "Contact" : "Adresatas",
    "Circle" : "Ratas",
    "Member" : "Narys",
    "Moderator" : "Moderatorius",
    "Admin" : "Administratorius",
    "Owner" : "Savininkas",
    "%s shared »%s« with you." : "%s pradėjo bendrinti »%s« su jumis.",
    "%s on %s" : "%s ant %s",
    "Password to access »%1$s« shared to you by %2$s" : "%2$s pasidalino slaptažodžiu, reikalingu atverti „%1$s“",
    "Password to access »%s«" : "Slaptažodis, skirtas prieigai prie „%s“",
    "It is protected with the following password:" : "Apsaugota šiuo slaptažodžiu:",
    "%1$s via %2$s" : "%1$s per %2$s",
    "Click the button below to open it." : "Norėdami jį atverti, spustelėkite mygtuką žemiau.",
    "Open »%s«" : "Atverti »%s«",
    "Password to access files shared to you by %1$s" : "Slaptažodis, skirtas pasiekti failus, kuriuos su jumis bendrino %1$s",
    "Password to access files" : "Prieigos prie failų slaptažodis",
    "%s shared multiple files with you." : "%s bendrino kelis failus su Jumis.",
    "Files" : "Failai",
    "This feature is not available for personal circles" : "Ši ypatybė nėra prieinama asmeniniams ratams",
    "This member is not a moderator" : "Šis narys nėra moderatorius",
    "Insufficient privileges" : "Nepakanka teisių",
    "This member does not exist" : "Šio nario nėra",
    "Level cannot be changed for this type of member" : "Šio tipo naudotojui negali būti pakeistas lygis.",
    "You are already a member of this circle" : "Jūs jau esate šio rato narys",
    "You have been blocked from this circle" : "Jūs buvote blokuotas šiame bendrinimo rate",
    "Accept" : "Priimti",
    "Refuse" : "Atsisakyti",
    "%s" : "%s",
    "No files in here" : "Čia failų nėra",
    "No entries found in this folder" : "Šiame aplanke nerasta jokių įrašų",
    "Name" : "Vardas",
    "Size" : "Dydis",
    "Modified" : "Pakeistas",
    "Shared to Circles" : "Bendrinama su  bendrystės ratu"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
